==> ae_sys_data-0.1.9.tar.gz: ae_sys_data-0.1.9/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sys_data portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_data/coverage/ae_sys_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_data/pylint.svg)](
    https://ae-group.gitlab.io/ae_sys_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_data)](
    https://libraries.io/pypi/ae-sys-data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/#files)


## installation


Execute the following command for to use the ae.sys_data module in your
application. It will install ae.sys_data into your python (virtual) environment:
 
```shell script
pip install ae-sys-data
```

If you instead want to contribute to this portion then first fork
[the ae_sys_data repository at GitLab](https://gitlab.com/ae-group/ae_sys_data "ae.sys_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_data):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_data.html#module-ae.sys_data
"ae_sys_data documentation").

<!-- Common files version 0.0.60 deployed version 0.1.9 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_sys_data module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-sys-data as namespace portion ae-sys-data.
-->

==> ae_sys_data-0.2.9.tar.gz: ae_sys_data-0.2.9/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# sys_data portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_data/coverage/ae_sys_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_data/pylint.svg)](
    https://ae-group.gitlab.io/ae_sys_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_data)](
    https://libraries.io/pypi/ae-sys-data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_data)](
    https://pypi.org/project/ae-sys-data/#files)


## installation


execute the following command to use the ae.sys_data module in your
application. it will install ae.sys_data into your python (virtual) environment:
 
```shell script
pip install ae-sys-data
```

if you instead want to contribute to this portion then first fork
[the ae_sys_data repository at GitLab](https://gitlab.com/ae-group/ae_sys_data "ae.sys_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_data):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_data.html#module-ae.sys_data
"ae_sys_data documentation").

<!-- common files version 0.2.77 deployed version 0.2.9 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_sys_data module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-sys-data as namespace portion ae-sys-data.
-->
